<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt" sourcelanguage="en">
<context>
    <name>Board</name>
    <message>
        <source>Details</source>
        <translation>Detalhes</translation>
    </message>
    <message>
        <source>Guess</source>
        <translation>Dar Palpite</translation>
    </message>
    <message>
        <source>Found</source>
        <translation>Encontradas</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Grande</translation>
    </message>
    <message>
        <source>Missed</source>
        <translation>Falhadas</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Sucesso</translation>
    </message>
    <message>
        <source>Game Over</source>
        <translation>Fim do Jogo</translation>
    </message>
    <message numerus="yes">
        <source>%1 of %n point(s)</source>
        <translation>
            <numerusform>%1 de %n ponto</numerusform>
            <numerusform>%1 de %n pontos</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>3 of %n point(s)</source>
        <translation>
            <numerusform>3 de %n ponto</numerusform>
            <numerusform>3 de %n pontos</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>2 of %n point(s)</source>
        <translation>
            <numerusform>2 de %n ponto</numerusform>
            <numerusform>2 de %n pontos</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>1 of %n point(s)</source>
        <translation>
            <numerusform>1 de %n ponto</numerusform>
            <numerusform>1 de %n pontos</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>0 of %n point(s)</source>
        <translation>
            <numerusform>0 de %n ponto</numerusform>
            <numerusform>0 de %n pontos</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n point(s)</source>
        <translation>
            <numerusform>%n ponto</numerusform>
            <numerusform>%n pontos</numerusform>
        </translation>
    </message>
    <message>
        <source>The maximum score was calculated from the following thirty words:</source>
        <translation>A pontuação máxima foi calculada das seguintes 30 palavras:</translation>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <source>m:ss</source>
        <translation>m:ss</translation>
    </message>
    <message numerus="yes">
        <source>%n guesses(s)</source>
        <translation>
            <numerusform>%n palpite</numerusform>
            <numerusform>%n palpites</numerusform>
        </translation>
    </message>
    <message>
        <source>+%1</source>
        <translation>+%1</translation>
    </message>
    <message numerus="yes">
        <source>%n strike(s)</source>
        <translation>
            <numerusform>%n tentativa</numerusform>
            <numerusform>%n tentativas</numerusform>
        </translation>
    </message>
    <message>
        <source>Tanglet</source>
        <translation>Tanglet</translation>
    </message>
    <message>
        <source>Classic</source>
        <translation>Clássico</translation>
    </message>
    <message>
        <source>Refill</source>
        <translation>Tornar a Encher</translation>
    </message>
    <message>
        <source>Stamina</source>
        <translation>Resistência</translation>
    </message>
    <message>
        <source>Strikeout</source>
        <translation>Três tentativas</translation>
    </message>
    <message>
        <source>Allotment</source>
        <translation>Lote</translation>
    </message>
    <message>
        <source>Discipline</source>
        <translation>Disciplina</translation>
    </message>
    <message>
        <source>Unlimited</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and increases on correct guesses.</source>
        <translation>Conta de 30 segundos para baixo e aumenta em palpites corretos</translation>
    </message>
    <message>
        <source>Counts down from 3 minutes.</source>
        <translation>Conta de 3 minutos para baixo.</translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and refills on correct guesses.</source>
        <translation>Conta de 30 segundos para baixo e torna a encher em palpites corretos.</translation>
    </message>
    <message>
        <source>Counts down from 45 seconds and pauses on correct guesses.</source>
        <translation>Conta de 45 segundos para baixo e pausa nos palpites corretos.</translation>
    </message>
    <message>
        <source>Game ends after 3 incorrect guesses.</source>
        <translation>O jogo termina após 3 palpites errados.</translation>
    </message>
    <message>
        <source>Game ends after 30 guesses.</source>
        <translation>O jogo termina após 30 palpites.</translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and increases or decreases on guesses.</source>
        <translation>Conta de 30 segundos para baixo e aumenta ou diminui nos palpites.</translation>
    </message>
    <message>
        <source>Game ends when all words are found.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Generator</name>
    <message>
        <source>Unable to read dice from file.</source>
        <translation>Não foi possível ler o dado do ficheiro.</translation>
    </message>
    <message>
        <source>Unable to read word list from file.</source>
        <translation>Não foi possível ler a lista de palavras do ficheiro.</translation>
    </message>
</context>
<context>
    <name>LanguageDialog</name>
    <message>
        <source>Board Language</source>
        <translation>Idioma do Tabuleiro</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Personalizado</translation>
    </message>
    <message>
        <source>Choose...</source>
        <translation>Escolher...</translation>
    </message>
    <message>
        <source>&lt;b&gt;Note:&lt;/b&gt; These settings will take effect when you start a new game.</source>
        <translation>&lt;b&gt;Nota:&lt;/b&gt; estas configurações surtirão efeito ao iniciar um novo jogo.</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Idioma:</translation>
    </message>
    <message>
        <source>Dice:</source>
        <translation>Dado:</translation>
    </message>
    <message>
        <source>Word list:</source>
        <translation>Lista de palavras:</translation>
    </message>
    <message>
        <source>Dictionary:</source>
        <translation>Dicionário:</translation>
    </message>
    <message>
        <source>Choose Dice File</source>
        <translation>Escolher Ficheiro de Dado</translation>
    </message>
    <message>
        <source>Choose Word List File</source>
        <translation>Escolher Ficheiro de Lista de Palavras</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Selecione o idioma da aplicação:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Idioma do Sistema&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Por favor reinicie esta aplicação para a alteração do idioma surtir efeito.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Novo Jogo</translation>
    </message>
    <message>
        <source>Amount of Words:</source>
        <translation>Quantidade de Palavras:</translation>
    </message>
    <message>
        <source>Minimum Word Length:</source>
        <translation>Comprimento Mínimo da Palavra:</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Baixo</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Médio</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Alto</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Aleatório</translation>
    </message>
    <message numerus="yes">
        <source>%n letter(s)</source>
        <translation>
            <numerusform>%n letra</numerusform>
            <numerusform>%n letras</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>High Scores</source>
        <translation>Pontuações Máximas</translation>
    </message>
    <message>
        <source>Rank</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Pontuação</translation>
    </message>
    <message>
        <source>Maximum</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>N/A</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>#%1</source>
        <translation>#%1</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tanglet</source>
        <translation>Tanglet</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Paused&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Click to resume playing.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Pausa&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Clique para continuar o jogo.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Loading game...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Por favor aguarde&lt;/big&gt;&lt;/b&gt;&lt;br&gt;A carregar o jogo...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Click to start a new game.</source>
        <translation>Clique para começar um novo jogo</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Generating a new board...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Por favor aguarde&lt;/big&gt;&lt;/b&gt;&lt;br&gt;A gerar um novo tabuleiro...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Optimizing word list...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Por favor aguarde&lt;/big&gt;&lt;/b&gt;&lt;br&gt;A optimizar a lista de palavras...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Jogo</translation>
    </message>
    <message>
        <source>New &amp;Game...</source>
        <translation>Novo &amp;Jogo</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>&amp;New Roll</source>
        <translation>&amp;Novo Dado</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Importar...</translation>
    </message>
    <message>
        <source>&amp;Share...</source>
        <translation>&amp;Partilhar...</translation>
    </message>
    <message>
        <source>&amp;End</source>
        <translation>&amp;Terminar</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pausa</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;Detalhes</translation>
    </message>
    <message>
        <source>&amp;High Scores</source>
        <translation>&amp;Pontuações Mais Altas</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Sair</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Configurações</translation>
    </message>
    <message>
        <source>Show &amp;Maximum Score</source>
        <translation>Mostrar Pontuação Mais Alta</translation>
    </message>
    <message>
        <source>&amp;Never</source>
        <translation>&amp;Nunca</translation>
    </message>
    <message>
        <source>&amp;End Of Game</source>
        <translation>&amp;Fim do Jogo</translation>
    </message>
    <message>
        <source>&amp;Always</source>
        <translation>&amp;Sempre</translation>
    </message>
    <message>
        <source>Show Missed &amp;Words</source>
        <translation>Mostrar Palavras &amp;Não Encontradas</translation>
    </message>
    <message>
        <source>Show Word &amp;Counts</source>
        <translation>Mostrar &amp;Contagens de Palavras</translation>
    </message>
    <message>
        <source>&amp;Board Language...</source>
        <translation>&amp;Idioma do Tabuleiro</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Idioma da &amp;Aplicação</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Controlos</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Sobre</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Sobre o &amp;Qt</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation>Direitos de autor &amp;copy; 2009-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Tanglet %1</source>
        <translation>Tanglet %1</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <source>A single player variant of &lt;a href=&quot;http://en.wikipedia.org/wiki/Boggle&quot;&gt;Boggle&lt;/a&gt;</source>
        <translation>Uma variante de jogador único do jogo &lt;a href=&quot;http://pt.wikipedia.org/wiki/Parole_(jogo)&quot;&gt;Parole&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Lançado sob a licença &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>English word list is based on &lt;a href=&quot;http://wordlist.sourceforge.net/&quot;&gt;SCOWL&lt;/a&gt; by Kevin Atkinson</source>
        <translation>A lista de palavras em Inglês é baseada em &lt;a href=&quot;http://wordlist.sourceforge.net/&quot;&gt;SCOWL&lt;/a&gt; por Kevin Atkinson</translation>
    </message>
    <message>
        <source>Hebrew word list is based on &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; by Nadav Har&apos;El and Dan Kenigsberg</source>
        <translation>A lista de palavras em Hebraico é baseada em &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; por Nadav Har&apos;El e Dan Kenigsberg</translation>
    </message>
    <message>
        <source>Import Game</source>
        <translation>importar Jogo</translation>
    </message>
    <message>
        <source>Tanglet Games (*.tanglet)</source>
        <translation>Jogos Tanglet (*.tanglet)</translation>
    </message>
    <message>
        <source>Unable to start requested game.</source>
        <translation>Não foi possível iniciar o jogo pedido.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <source>Export Game</source>
        <translation>Exportar Jogo</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Questão</translation>
    </message>
    <message>
        <source>End the current game?</source>
        <translation>Terminar o jogo atual?</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalhes</translation>
    </message>
    <message>
        <source>Board Size:</source>
        <translation>Tamanho do Tabuleiro:</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Grande</translation>
    </message>
    <message>
        <source>Word Density:</source>
        <translation>Densidade de Palavras:</translation>
    </message>
    <message>
        <source>Word Length:</source>
        <translation>Comprimento das Palavras:</translation>
    </message>
    <message>
        <source>%1 or more letters</source>
        <translation>%1 ou mais letras</translation>
    </message>
    <message>
        <source>Game Type:</source>
        <translation>Tipo de Jogo:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>dESCRIÇÃO:</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Controlos</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Mouse Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Click on the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Click on the last selected letter.&lt;br&gt;&lt;b&gt;Erase letters:&lt;/b&gt; Click on an earlier selected letter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Click twice on the first selected letter.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Keyboard Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Type the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Press Enter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Press Ctrl+Backspace.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Jogar com o Rato:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Selecionar palavra:&lt;/b&gt; Clicar nas letras de uma palavra.&lt;br&gt;&lt;b&gt;Dar um palpite:&lt;/b&gt; Clicar na última letra selecionada.&lt;br&gt;&lt;b&gt;Limpar letras:&lt;/b&gt; Clicar numa letra selecionada anteriormente.&lt;br&gt;&lt;b&gt;Limpar a palavra:&lt;/b&gt; Clicar 2 vezes na primeira letra selecionada.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Jogar com o Teclado:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Selecionar palavra:&lt;/b&gt; Digitar as letras da palavra.&lt;br&gt;&lt;b&gt;Dar um palpite:&lt;/b&gt; Pressionar a tecla Enter.&lt;br&gt;&lt;b&gt;Limpar a palavra:&lt;/b&gt; Pressionar as teclas Ctrl+Apagar.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WordCounts</name>
    <message>
        <source>Letters:</source>
        <translation>Letras:</translation>
    </message>
    <message>
        <source>Found:</source>
        <translation>Encontrado:</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;&lt;b&gt;%2&lt;/b&gt;</source>
        <translation>%1&lt;br&gt;&lt;b&gt;%2&lt;/b&gt;</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;&lt;b&gt;%2/%3&lt;/b&gt;</source>
        <translation>%1&lt;br&gt;&lt;b&gt;%2/%3&lt;/b&gt;</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;%2/%3</source>
        <translation>%1&lt;br&gt;%2/%3</translation>
    </message>
</context>
<context>
    <name>WordTree</name>
    <message numerus="yes">
        <source>%n point(s)</source>
        <translation>
            <numerusform>%n ponto</numerusform>
            <numerusform>%n pontos</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Word finding game</source>
        <translation>Jogo de encontrar palavras</translation>
    </message>
    <message>
        <source>A game file to play.</source>
        <translation>Um ficheiro de jogo para jogar.</translation>
    </message>
</context>
</TS>
